@@ -1,5 +1,6 @@
 import torch
 from .preprocessing import preprocess_tweet
+import transformers
 from transformers import (
     AutoTokenizer, AutoModelForSequenceClassification, AutoModelForTokenClassification,
     DataCollatorWithPadding,
@@ -10,6 +11,8 @@ from datasets import Dataset
 from torch.nn import functional as F
 
 
+transformers.logging.set_verbosity_error()
+
 models = {
     "es": {
         "sentiment": {
@@ -325,7 +328,10 @@ class AnalyzerForTokenClassification(BaseAnalyzer):
         current_words = None
         current_type = None
         for token, label in zip(words, labels):
-            if label == 'O':
+            if label is None:
+                # Perhaps it is too long
+                continue
+            elif label == 'O':
                 if current_type == "O":
                     pass
                 else:
